SeqMonk - A Mapped Sequence Analysis tool
---------------------------------------

SeqMonk is a tool for viewing and analysing mapped sequence data.  It
was initially written to cope with remapping experiment data from
next generation sequencers, but could be applied to any dataset
consisting of a series of mapped genomic regions.  The program allows
you to visualise the positions of your mapped regions against an
annotated genome and to quantify the data in order to make comparisons
between data sets.

SeqMonk is a cross-platform application, written in java.  In theory it
should run on any platform which has a suitable java runtime environment.
It requires at least java 8 (v1.8) and should run on any of the major
operating systems.

If you have any comments about SeqMonk we would like to hear them.  You
can either enter them in our bug tracking system at:

https://github.com/s-andrews/seqmonk/issues/

..or send them directly to simon.andrews@babraham.ac.uk.

